Change in vdsm[master]: WIP: rename stats cache to vm stats cache

fromani at redhat.com fromani at redhat.com
Tue Apr 28 15:55:35 UTC 2015


Francesco Romani has uploaded a new change for review.

Change subject: WIP: rename stats cache to vm stats cache
......................................................................

WIP: rename stats cache to vm stats cache

Future patch want to modernize HostStats* and
port it to periodic Operations infrastructure.
To make room for this change and reduce
ambiguity, re-introduced the ubiquitous
vm* prefix.

No changes besides naming.

Change-Id: If38c49f686dfc2bc0994d444ff24c7736f2e951b
Signed-off-by: Francesco Romani <fromani at redhat.com>
---
M tests/samplingTests.py
M tests/vmfakelib.py
M vdsm/virt/periodic.py
M vdsm/virt/sampling.py
M vdsm/virt/vm.py
5 files changed, 16 insertions(+), 16 deletions(-)


  git pull ssh://gerrit.ovirt.org:29418/vdsm refs/changes/71/40371/1

diff --git a/tests/samplingTests.py b/tests/samplingTests.py
index 2624dd7..1f2a65c 100644
--- a/tests/samplingTests.py
+++ b/tests/samplingTests.py
@@ -250,13 +250,13 @@
             self.assertTrue(self._sampleCount >= self.STOP_SAMPLE)
 
 
-class StatsCacheTests(TestCaseBase):
+class VmStatsCacheTests(TestCaseBase):
 
     FAKE_CLOCK_STEP = 1
 
     def setUp(self):
         self.clock = 0
-        self.cache = sampling.StatsCache(clock=self.fake_monotonic_time)
+        self.cache = sampling.VmStatsCache(clock=self.fake_monotonic_time)
 
     def fake_monotonic_time(self):
         self.clock += self.FAKE_CLOCK_STEP
diff --git a/tests/vmfakelib.py b/tests/vmfakelib.py
index d8ce6ce..544eb5a 100644
--- a/tests/vmfakelib.py
+++ b/tests/vmfakelib.py
@@ -201,7 +201,7 @@
             fake._guestCpuRunning = runCpu
             if status is not None:
                 fake._lastStatus = status
-            sampling.stats_cache.add(fake.id)
+            sampling.vm_stats_cache.add(fake.id)
             yield fake
 
 
diff --git a/vdsm/virt/periodic.py b/vdsm/virt/periodic.py
index a3f8cc6..00615c3 100644
--- a/vdsm/virt/periodic.py
+++ b/vdsm/virt/periodic.py
@@ -94,7 +94,7 @@
             sampling.VMBulkSampler(
                 libvirtconnection.get(cif),
                 cif.getVMs,
-                sampling.stats_cache),
+                sampling.vm_stats_cache),
             config.getint('vars', 'vm_sample_interval')),
 
         # we do this only until we get high water mark notifications
diff --git a/vdsm/virt/vm.py b/vdsm/virt/vm.py
index dcc215b..2b7e3eb 100644
--- a/vdsm/virt/vm.py
+++ b/vdsm/virt/vm.py
@@ -1308,7 +1308,7 @@
 
         decStats = {}
         try:
-            vm_sample = sampling.stats_cache.get(self.id)
+            vm_sample = sampling.vm_stats_cache.get(self.id)
             decStats = vmstats.produce(self,
                                        vm_sample.first_value,
                                        vm_sample.last_value,
@@ -1675,7 +1675,7 @@
                                                               nic.name)
 
         self._guestEventTime = self._startTime
-        sampling.stats_cache.add(self.id)
+        sampling.vm_stats_cache.add(self.id)
         try:
             self.guestAgent.connect()
         except Exception:
@@ -3454,7 +3454,7 @@
             self.lastStatus = vmstatus.POWERING_DOWN
             # Terminate the VM's creation thread.
             self._incomingMigrationFinished.set()
-            sampling.stats_cache.remove(self.id)
+            sampling.vm_stats_cache.remove(self.id)
             self.guestAgent.stop()
             if self._dom:
                 result = self._destroyVmGraceful()


diff --git a/vdsm/virt/sampling.py b/vdsm/virt/sampling.py
index 6804406..89f109b 100644
--- a/vdsm/virt/sampling.py
+++ b/vdsm/virt/sampling.py
@@ -375,7 +375,7 @@
 EMPTY_SAMPLE = StatsSample(None, None, None, None)
 
 
-class StatsCache(object):
+class VmStatsCache(object):
     """
     Cache for bulk stats samples.
     Provide facilities to retrieve per-vm samples, and the glue code to deal
@@ -391,7 +391,7 @@
 
     VDSM has countermeasures for those cases. Stuck threads are replaced,
     thanks to Executor. But still, before to be destroyed, a replaced
     thread can mistakenly try to add a sample to a StatsCache.
 
     Because of worker thread replacement, that sample from stuck thread
     can  be stale.
@@ -402,7 +402,7 @@
     between a well behaving call and an unblocked stuck call.
     """
 
-    _log = logging.getLogger("sampling.StatsCache")
+    _log = logging.getLogger("sampling.VmStatsCache")
 
     def __init__(self, clock=utils.monotonic_time):
         self._clock = clock
@@ -478,7 +478,7 @@
             self._vm_last_timestamp[vmid] = monotonic_ts
 
 
-stats_cache = StatsCache()
+vm_stats_cache = VmStatsCache()
 
 
 # this value can be tricky to tune.
@@ -492,18 +492,18 @@
 
 
 class VMBulkSampler(object):
-    def __init__(self, conn, get_vms, stats_cache,
+    def __init__(self, conn, get_vms, vm_stats_cache,
                  stats_flags=0, timeout=_TIMEOUT):
         self._conn = conn
         self._get_vms = get_vms
-        self._stats_cache = stats_cache
+        self._vm_stats_cache = vm_stats_cache
         self._stats_flags = stats_flags
         self._skip_doms = ExpiringCache(timeout)
         self._sampling = Stage()
         self._log = logging.getLogger("sampling.VMBulkSampler")
 
     def __call__(self):
-        timestamp = self._stats_cache.clock()
+        timestamp = self._vm_stats_cache.clock()
         # we are deep in the hot path. bool(ExpiringCache)
         # *is* costly so we should avoid it if we can.
         fast_path = (self._sampling.empty and not self._skip_doms)
@@ -514,7 +514,7 @@
                 # If everything's ok, we can skip all the costly checks.
                 bulk_stats = self._conn.getAllDomainStats(
                     self._stats_flags)
-                self._stats_cache.put(_translate(bulk_stats), timestamp)
+                self._vm_stats_cache.put(_translate(bulk_stats), timestamp)
             else:
                 # A previous call got stuck, or not every domain
                 # has properly recovered. Thus we must whitelist domains.
@@ -523,7 +523,7 @@
                 if doms:
                     bulk_stats = self._conn.domainListGetStats(
                         doms, self._stats_flags)
-                    self._stats_cache.put(_translate(bulk_stats), timestamp)
+                    self._vm_stats_cache.put(_translate(bulk_stats), timestamp)
 
     def _get_responsive_doms(self):
         vms = self._get_vms()
@@ -391,7 +391,7 @@
     VDSM has countermeasures for those cases. Stuck threads are replaced,
     thanks to Executor. But still, before to be destroyed, a replaced
-    thread can mistakenly try to add a sample to a StatsCache.
+    thread can mistakenly try to add a sample to a VmStatsCache.
 
     Because of worker thread replacement, that sample from stuck thread
-- 
To view, visit https://gerrit.ovirt.org/40371
To unsubscribe, visit https://gerrit.ovirt.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: If38c49f686dfc2bc0994d444ff24c7736f2e951b
Gerrit-PatchSet: 1
Gerrit-Project: vdsm
Gerrit-Branch: master
Gerrit-Owner: Francesco Romani <fromani at redhat.com>


More information about the vdsm-patches mailing list